@@ -14,16 +14,15 @@
 #    under the License.
 
 import os
-import subprocess
 import sys
-import warnings
 
 sys.path.insert(0, os.path.abspath('../..'))
 # -- General configuration ----------------------------------------------------
 
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
-extensions = ['sphinx.ext.autodoc', 'openstackdocstheme']
+extensions = ['openstackdocstheme',
+              'sphinxcontrib.apidoc']
 
 # openstackdocstheme options
 repository_name = 'openstack/glance_store'
@@ -31,6 +30,14 @@ bug_project = 'glance-store'
 bug_tag = ''
 html_last_updated_fmt = '%Y-%m-%d %H:%M'
 
+# sphinxcontrib.apidoc options
+apidoc_module_dir = '../../glance_store'
+apidoc_output_dir = 'reference/api'
+apidoc_excluded_paths = [
+    'test',
+    'tests/*']
+apidoc_separate_modules = True
+
 # autodoc generation is a bit aggressive and a nuisance when doing heavy
 # text edit cycles.
 # execute "export SPHINX_DEBUG=1" in your terminal to disable
@@ -72,14 +79,6 @@ htmlhelp_basename = '%sdoc' % project
 
 modindex_common_prefix = ['glance_store.']
 
-git_cmd = ["git", "log", "--pretty=format:'%ad, commit %h'", "--date=local",
-           "-n1"]
-try:
-    html_last_updated_fmt = subprocess.check_output(git_cmd).decode('utf-8')
-except Exception:
-    warnings.warn('Cannot get last updated time from git repository. '
-                  'Not setting "html_last_updated_fmt".')
-
 # Grouping the document tree into LaTeX files. List of tuples
 # (source start file, target name, title, author, documentclass
 # [howto/manual]).
