@@ -43,7 +43,6 @@ except ImportError:
     rbd = None
 
 DEFAULT_POOL = 'images'
-DEFAULT_CONFFILE = '/etc/ceph/ceph.conf'
 DEFAULT_USER = None    # let librados decide based on the Ceph conf file
 DEFAULT_CHUNKSIZE = 8  # in MiB
 DEFAULT_SNAPNAME = 'snap'
@@ -110,16 +109,23 @@ Related options:
     * rbd_store_ceph_conf
 
 """),
-    cfg.StrOpt('rbd_store_ceph_conf', default=DEFAULT_CONFFILE,
+    cfg.StrOpt('rbd_store_ceph_conf', default='',
                help="""
 Ceph configuration file path.
 
-This configuration option takes in the path to the Ceph configuration
+This configuration option specifies the path to the Ceph configuration
 file to be used. If the value for this option is not set by the user
-or is set to None, librados will locate the default configuration file
-which is located at /etc/ceph/ceph.conf. If using Cephx
-authentication, this file should include a reference to the right
-keyring in a client.<USER> section
+or is set to the empty string, librados will read the standard ceph.conf
+file by searching the default Ceph configuration file locations in
+sequential order.  See the Ceph documentation for details.
+
+NOTE: If using Cephx authentication, this file should include a reference
+to the right keyring in a client.<USER> section
+
+NOTE 2: If you leave this option empty (the default), the actual Ceph
+configuration file used may change depending on what version of librados
+is being used.  If it is important for you to know exactly which configuration
+file is in effect, you may specify that file here using this option.
 
 Possible Values:
     * A valid path to a configuration file
@@ -313,6 +319,23 @@ class Store(driver.Store):
             LOG.error(reason)
             raise exceptions.BadStoreConfiguration(store_name='rbd',
                                                    reason=reason)
+        if self.backend_group:
+            self._set_url_prefix()
+
+    def _set_url_prefix(self):
+        fsid = None
+        with self.get_connection(conffile=self.conf_file,
+                                 rados_id=self.user) as conn:
+            if hasattr(conn, 'get_fsid'):
+                fsid = encodeutils.safe_decode(conn.get_fsid())
+
+        if fsid and self.pool:
+            # ensure nothing contains / or any other url-unsafe character
+            safe_fsid = urllib.parse.quote(fsid, '')
+            safe_pool = urllib.parse.quote(self.pool, '')
+            self._url_prefix = "rbd://%s/%s/" % (safe_fsid, safe_pool)
+        else:
+            self._url_prefix = "rbd://"
 
     @capabilities.check
     def get(self, location, offset=0, chunk_size=None, context=None):
@@ -565,7 +588,7 @@ class Store(driver.Store):
         # Add store backend information to location metadata
         metadata = {}
         if self.backend_group:
-            metadata['backend'] = u"%s" % self.backend_group
+            metadata['store'] = u"%s" % self.backend_group
 
         return (loc.get_uri(),
                 image_size,
