@@ -190,7 +190,9 @@ class TestMultiStore(base.MultiStoreBaseTest,
         # Ensure stores + locations cleared
         g_location.SCHEME_TO_CLS_BACKEND_MAP = {}
 
-        store.create_multi_stores(self.conf)
+        with mock.patch.object(rbd_store.Store, '_set_url_prefix'):
+            store.create_multi_stores(self.conf)
+
         self.addCleanup(setattr, g_location, 'SCHEME_TO_CLS_BACKEND_MAP',
                         dict())
         self.addCleanup(self.conf.reset)
@@ -212,6 +214,10 @@ class TestMultiStore(base.MultiStoreBaseTest,
         self.data_len = 3 * units.Ki
         self.data_iter = six.BytesIO(b'*' * self.data_len)
 
+    def test_location_url_prefix_is_set(self):
+        expected_url_prefix = "rbd://"
+        self.assertEqual(expected_url_prefix, self.store.url_prefix)
+
     def test_add_w_image_size_zero(self):
         """Assert that correct size is returned even though 0 was provided."""
         self.store.chunk_size = units.Ki
@@ -222,7 +228,7 @@ class TestMultiStore(base.MultiStoreBaseTest,
                 self.assertTrue(resize.called)
                 self.assertTrue(write.called)
                 self.assertEqual(ret[1], self.data_len)
-                self.assertEqual("ceph1", ret[3]['backend'])
+                self.assertEqual("ceph1", ret[3]['store'])
 
     def test_add_w_image_size_zero_to_different_backend(self):
         """Assert that correct size is returned even though 0 was provided."""
@@ -246,7 +252,7 @@ class TestMultiStore(base.MultiStoreBaseTest,
                 self.assertTrue(resize.called)
                 self.assertTrue(write.called)
                 self.assertEqual(ret[1], self.data_len)
-                self.assertEqual("ceph2", ret[3]['backend'])
+                self.assertEqual("ceph2", ret[3]['store'])
 
     @mock.patch.object(MockRBD.Image, '__enter__')
     @mock.patch.object(rbd_store.Store, '_create_image')
